@@ -93,7 +93,11 @@ public:
     {
     }
 
+#if LLVM_VERSION_MAJOR >= 10
+    std::unique_ptr<FrontendAction> create() override
+#else
     FrontendAction *create() override
+#endif
     {
         ClazyContext::ClazyOptions options = ClazyContext::ClazyOption_None;
 
@@ -116,28 +120,22 @@ public:
             options |= ClazyContext::ClazyOption_IgnoreIncludedFiles;
 
         // TODO: We need to agregate the fixes with previous run
+#if LLVM_VERSION_MAJOR >= 10
+        return std::make_unique<ClazyStandaloneASTAction>(s_checks.getValue(), s_headerFilter.getValue(),
+                                                          s_ignoreDirs.getValue(), s_exportFixes.getValue(),
+                                                          m_paths, options);
+#else
         return new ClazyStandaloneASTAction(s_checks.getValue(), s_headerFilter.getValue(),
                                             s_ignoreDirs.getValue(), s_exportFixes.getValue(),
                                             m_paths, options);
+#endif
     }
     std::vector<std::string> m_paths;
 };
 
 int main(int argc, const char **argv)
 {
-#if LLVM_VERSION_MAJOR >= 9
-    /* HACK: cl::ZeroOrMore makes clazy-standalone stop working for some reason (with llvm-9).
-     * optionsParser.getSourcePathList() returns 0, even with a command as simple as:
-     *     clang-standalone main.cpp
-     * The exact same command line works in clang-tidy, which has the same CommonOptionsParser code.
-     * Commented for now to figure if it's a compiler bug on my archlinux.
-     */
-    auto numOccurrencesFlag = cl::OneOrMore;
-#else
-    auto numOccurrencesFlag = cl::ZeroOrMore;
-#endif
-
-    CommonOptionsParser optionsParser(argc, argv, s_clazyCategory, numOccurrencesFlag);
+    CommonOptionsParser optionsParser(argc, argv, s_clazyCategory, cl::ZeroOrMore);
     // llvm::errs() << optionsParser.getSourcePathList().size() << "\n";
 
     if (s_supportedChecks.getValue()) {
